@@ -1,6 +1,6 @@
 #[JW for editor]:mode=perl:tabSize=8:indentSize=2:noTabs=true:indentOnEnter=true:
 package Config::IniFiles;
-$Config::IniFiles::VERSION = (qw($Revision: 2.25 $))[1];
+$Config::IniFiles::VERSION = (qw($Revision: 2.26 $))[1];
 require 5.004;
 use strict;
 use Carp;
@@ -8,7 +8,7 @@ use Symbol 'gensym','qualify_to_ref';   # For the 'any data type' hack
 
 @Config::IniFiles::errors = ( );
 
-#	$Header: /cvsroot/config-inifiles/config-inifiles/IniFiles.pm,v 2.25 2001/12/12 20:44:48 wadg Exp $
+#	$Header: /cvsroot/config-inifiles/config-inifiles/IniFiles.pm,v 2.26 2001/12/19 22:20:50 wadg Exp $
 
 =head1 NAME
 
@@ -432,6 +432,18 @@ sub ReadConfig {
   local $_;
   my @lines = split /\015\012?|\012/, join( '', <$fh>);
   close($fh);
+
+  # The first lines of the file must be blank, comments or start with [
+  my $first = '';
+  foreach ( @lines ) {
+    next if /^\s*$/;	# ignore blank lines
+    next if /^\s*\#/;	# ignore comments
+    $first = $_;
+    last;
+  }
+  unless( $first =~ /^\s*\[/ ) {
+    return undef;
+  }
   
   # Store what our line ending char was for output
   ($self->{line_ends}) = $lines[0] =~ /([\015\012]+)/;
@@ -1900,11 +1912,14 @@ modify it under the same terms as Perl itself.
 =head1 Change log
 
      $Log: IniFiles.pm,v $
+     Revision 2.26  2001/12/19 22:20:50  wadg
+     #481513 Recognize badly formatted files
+
      Revision 2.25  2001/12/12 20:44:48  wadg
      Update to bring CVS version in synch
 
      Revision 2.24  2001/12/07 10:03:06  wadg
-     222444 Abilite to load from arbitrary source
+     222444 Ability to load from arbitrary source
 
      Revision 2.23  2001/12/07 09:35:06  wadg
      Forgot to include updates t/test.ini
